Security Advisories (2)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

CPANSA-Jifty-2009-01 (2009-04-09)

The REST plugin would let you call any method on the model.

NAME

Jifty::Web::Form::Field::Button - Add buttons to your forms

SUMMARY

"" in Jifty::Web::Form::Field::Button is a Jifty::Web::Form::Field

METHODS

accessors

Provide the button_as_link accessor (in addition to Jifty::Web::Form::Field's default accessors), which controls if the button is reworked in javascript to appear as a link.

render_widget

Renders the button widget.